@@ -14,24 +14,17 @@
 #include <boost/mpl/if.hpp>
 #include <boost/mpl/or.hpp>
 
-namespace boost { namespace network { namespace detail {
-    
-    template <class Tag>
-    struct string_value :
-        mpl::if_<
-            is_async<Tag>,
-            boost::shared_future<typename string<Tag>::type>,
-            typename mpl::if_<
-                mpl::or_<
-                    is_sync<Tag>,
-                    is_same<Tag, tags::default_string>,
-                    is_same<Tag, tags::default_wstring>
-                >,
-                typename string<Tag>::type,
-                unsupported_tag<Tag>
-            >::type
-        >
-    {};
+namespace boost {
+namespace network {
+namespace detail {
+
+template <class Tag>
+struct string_value
+    : mpl::if_<is_async<Tag>, boost::shared_future<typename string<Tag>::type>,
+               typename mpl::if_<
+                   mpl::or_<is_sync<Tag>, is_same<Tag, tags::default_string>,
+                            is_same<Tag, tags::default_wstring> >,
+                   typename string<Tag>::type, unsupported_tag<Tag> >::type> {};
 
 } /* detail */
 } /* network */
