@@ -68,15 +68,21 @@ struct http_async_connection
       connection_delegate_ptr;
 
   http_async_connection(resolver_type& resolver, resolve_function resolve,
-                        bool follow_redirect, connection_delegate_ptr delegate)
-      : follow_redirect_(follow_redirect),
+                        bool follow_redirect, int timeout,
+                        connection_delegate_ptr delegate)
+      : timeout_(timeout),
+        timer_(resolver.get_io_service()),
+        is_timedout_(false),
+        follow_redirect_(follow_redirect),
         resolver_(resolver),
         resolve_(resolve),
         request_strand_(resolver.get_io_service()),
         delegate_(delegate) {}
 
-  // This is the main entry point for the connection/request pipeline. We're
-  // overriding async_connection_base<...>::start(...) here which is called
+  // This is the main entry point for the connection/request pipeline.
+  // We're
+  // overriding async_connection_base<...>::start(...) here which is
+  // called
   // by the client.
   virtual response start(request const& request, string_type const& method,
                          bool get_body, body_callback_function_type callback,
@@ -88,10 +94,20 @@ struct http_async_connection
                   &command_streambuf));
     this->method = method;
     boost::uint16_t port_ = port(request);
-    resolve_(resolver_, host(request), port_,
+	string_type host_ = host(request);
+	boost::uint16_t source_port = request.source_port();
+
+    resolve_(resolver_, host_, port_,
              request_strand_.wrap(boost::bind(
                  &this_type::handle_resolved, this_type::shared_from_this(),
-                 port_, get_body, callback, generator, _1, _2)));
+                 host_, port_, source_port, get_body, callback,
+                 generator, boost::arg<1>(), boost::arg<2>())));
+    if (timeout_ > 0) {
+      timer_.expires_from_now(boost::posix_time::seconds(timeout_));
+      timer_.async_wait(request_strand_.wrap(
+          boost::bind(&this_type::handle_timeout, this_type::shared_from_this(),
+                      boost::arg<1>())));
+    }
     return response_;
   }
 
@@ -107,24 +123,32 @@ struct http_async_connection
     this->source_promise.set_exception(boost::copy_exception(error));
     this->destination_promise.set_exception(boost::copy_exception(error));
     this->body_promise.set_exception(boost::copy_exception(error));
+    this->timer_.cancel();
   }
 
-  void handle_resolved(boost::uint16_t port, bool get_body,
+  void handle_timeout(boost::system::error_code const& ec) {
+    if (!ec) delegate_->disconnect();
+    is_timedout_ = true;
+  }
+
+  void handle_resolved(string_type host, boost::uint16_t port, boost::uint16_t source_port, bool get_body,
                        body_callback_function_type callback,
                        body_generator_function_type generator,
                        boost::system::error_code const& ec,
                        resolver_iterator_pair endpoint_range) {
     if (!ec && !boost::empty(endpoint_range)) {
-      // Here we deal with the case that there was an error encountered and
+      // Here we deal with the case that there was an error encountered
+      // and
       // that there's still more endpoints to try connecting to.
       resolver_iterator iter = boost::begin(endpoint_range);
       asio::ip::tcp::endpoint endpoint(iter->endpoint().address(), port);
       delegate_->connect(
-          endpoint, request_strand_.wrap(boost::bind(
-                        &this_type::handle_connected,
-                        this_type::shared_from_this(), port, get_body, callback,
-                        generator, std::make_pair(++iter, resolver_iterator()),
-                        placeholders::error)));
+          endpoint, host, source_port,
+          request_strand_.wrap(boost::bind(
+              &this_type::handle_connected, this_type::shared_from_this(), host,
+              port, source_port, get_body, callback, generator,
+              std::make_pair(++iter, resolver_iterator()),
+              placeholders::error)));
     } else {
       set_errors(ec ? ec : boost::asio::error::host_not_found);
       boost::iterator_range<const char*> range;
@@ -132,12 +156,14 @@ struct http_async_connection
     }
   }
 
-  void handle_connected(boost::uint16_t port, bool get_body,
+  void handle_connected(string_type host, boost::uint16_t port, boost::uint16_t source_port, bool get_body,
                         body_callback_function_type callback,
                         body_generator_function_type generator,
                         resolver_iterator_pair endpoint_range,
                         boost::system::error_code const& ec) {
-    if (!ec) {
+    if (is_timedout_) {
+      set_errors(asio::error::timed_out);
+    } else if (!ec) {
       BOOST_ASSERT(delegate_.get() != 0);
       delegate_->write(
           command_streambuf,
@@ -150,10 +176,10 @@ struct http_async_connection
         resolver_iterator iter = boost::begin(endpoint_range);
         asio::ip::tcp::endpoint endpoint(iter->endpoint().address(), port);
         delegate_->connect(
-            endpoint,
+            endpoint, host, source_port,
             request_strand_.wrap(boost::bind(
                 &this_type::handle_connected, this_type::shared_from_this(),
-                port, get_body, callback, generator,
+                host, port, source_port, get_body, callback, generator,
                 std::make_pair(++iter, resolver_iterator()),
                 placeholders::error)));
       } else {
@@ -176,13 +202,18 @@ struct http_async_connection
                            body_generator_function_type generator,
                            boost::system::error_code const& ec,
                            std::size_t bytes_transferred) {
-    if (!ec) {
+    // TODO(dberris): review parameter necessity.
+    (void)bytes_transferred;
+
+    if (!is_timedout_ && !ec) {
       if (generator) {
-        // Here we write some more data that the generator provides, before
+        // Here we write some more data that the generator provides,
+        // before
         // we wait for data from the server.
         string_type chunk;
         if (generator(chunk)) {
-          // At this point this means we have more data to write, so we write
+          // At this point this means we have more data to write, so we
+          // write
           // it out.
           std::copy(chunk.begin(), chunk.end(),
                     std::ostreambuf_iterator<typename char_<Tag>::type>(
@@ -204,7 +235,7 @@ struct http_async_connection
               version, get_body, callback, placeholders::error,
               placeholders::bytes_transferred)));
     } else {
-      set_errors(ec);
+      set_errors(is_timedout_ ? asio::error::timed_out : ec);
     }
   }
 
@@ -220,11 +251,13 @@ struct http_async_connection
 #else
         false && short_read_error;
 #endif
-    if (!ec || ec == boost::asio::error::eof || is_ssl_short_read_error) {
+    if (!is_timedout_ &&
+        (!ec || ec == boost::asio::error::eof || is_ssl_short_read_error)) {
       logic::tribool parsed_ok;
       size_t remainder;
       switch (state) {
         case version:
+          if (ec == boost::asio::error::eof) return;
           parsed_ok = this->parse_version(
               delegate_,
               request_strand_.wrap(boost::bind(
@@ -234,6 +267,7 @@ struct http_async_connection
               bytes_transferred);
           if (!parsed_ok || indeterminate(parsed_ok)) return;
         case status:
+          if (ec == boost::asio::error::eof) return;
           parsed_ok = this->parse_status(
               delegate_,
               request_strand_.wrap(boost::bind(
@@ -243,6 +277,7 @@ struct http_async_connection
               bytes_transferred);
           if (!parsed_ok || indeterminate(parsed_ok)) return;
         case status_message:
+          if (ec == boost::asio::error::eof) return;
           parsed_ok = this->parse_status_message(
               delegate_, request_strand_.wrap(boost::bind(
                              &this_type::handle_received_data,
@@ -252,8 +287,11 @@ struct http_async_connection
               bytes_transferred);
           if (!parsed_ok || indeterminate(parsed_ok)) return;
         case headers:
-          // In the following, remainder is the number of bytes that remain
-          // in the buffer. We need this in the body processing to make sure
+          if (ec == boost::asio::error::eof) return;
+          // In the following, remainder is the number of bytes that
+          // remain
+          // in the buffer. We need this in the body processing to make
+          // sure
           // that the data remaining in the buffer is dealt with before
           // another call to get more data for the body is scheduled.
           fusion::tie(parsed_ok, remainder) = this->parse_headers(
@@ -289,13 +327,15 @@ struct http_async_connection
             typename protocol_base::buffer_type::const_iterator end = begin;
             std::advance(end, remainder);
 
-            // We're setting the body promise here to an empty string because
+            // We're setting the body promise here to an empty string
+            // because
             // this can be used as a signaling mechanism for the user to
             // determine that the body is now ready for processing, even
             // though the callback is already provided.
             this->body_promise.set_value("");
 
-            // The invocation of the callback is synchronous to allow us to
+            // The invocation of the callback is synchronous to allow us
+            // to
             // wait before scheduling another read.
             callback(make_iterator_range(begin, end), ec);
 
@@ -321,8 +361,10 @@ struct http_async_connection
         case body:
           if (ec == boost::asio::error::eof || is_ssl_short_read_error) {
             // Here we're handling the case when the connection has been
-            // closed from the server side, or at least that the end of file
-            // has been reached while reading the socket. This signals the end
+            // closed from the server side, or at least that the end of
+            // file
+            // has been reached while reading the socket. This signals
+            // the end
             // of the body processing chain.
             if (callback) {
               typename protocol_base::buffer_type::const_iterator
@@ -330,8 +372,10 @@ struct http_async_connection
                   end = begin;
               std::advance(end, bytes_transferred);
 
-              // We call the callback function synchronously passing the error
-              // condition (in this case, end of file) so that it can handle
+              // We call the callback function synchronously passing the
+              // error
+              // condition (in this case, end of file) so that it can
+              // handle
               // it appropriately.
               callback(make_iterator_range(begin, end), ec);
             } else {
@@ -348,13 +392,16 @@ struct http_async_connection
             this->source_promise.set_value("");
             this->part.assign('\0');
             this->response_parser_.reset();
+            this->timer_.cancel();
           } else {
-            // This means the connection has not been closed yet and we want
+            // This means the connection has not been closed yet and we
+            // want
             // to get more
             // data.
             if (callback) {
               // Here we have a body_handler callback. Let's invoke the
-              // callback from here and make sure we're getting more data
+              // callback from here and make sure we're getting more
+              // data
               // right after.
               typename protocol_base::buffer_type::const_iterator begin =
                   this->part.begin();
@@ -387,7 +434,8 @@ struct http_async_connection
           BOOST_ASSERT(false && "Bug, report this to the developers!");
       }
     } else {
-      boost::system::system_error error(ec);
+      boost::system::system_error error(is_timedout_ ? asio::error::timed_out
+                                                     : ec);
       this->source_promise.set_exception(boost::copy_exception(error));
       this->destination_promise.set_exception(boost::copy_exception(error));
       switch (state) {
@@ -401,7 +449,12 @@ struct http_async_connection
         case headers:
           this->headers_promise.set_exception(boost::copy_exception(error));
         case body:
-          this->body_promise.set_exception(boost::copy_exception(error));
+          if (!callback) {
+            // N.B. if callback is non-null, then body_promise has
+            // already been set to value "" to indicate body is
+            // handled by streaming handler so no exception should be set
+            this->body_promise.set_exception(boost::copy_exception(error));
+          }
           break;
         default:
           BOOST_ASSERT(false && "Bug, report this to the developers!");
@@ -436,6 +489,9 @@ struct http_async_connection
     return body;
   }
 
+  int timeout_;
+  boost::asio::deadline_timer timer_;
+  bool is_timedout_;
   bool follow_redirect_;
   resolver_type& resolver_;
   resolve_function resolve_;
