@@ -35,13 +35,14 @@ struct connection_delegate_factory {
       asio::io_service& service, bool https, bool always_verify_peer,
       optional<string_type> certificate_filename,
       optional<string_type> verify_path, optional<string_type> certificate_file,
-      optional<string_type> private_key_file) {
+      optional<string_type> private_key_file, optional<string_type> ciphers,
+      long ssl_options) {
     connection_delegate_ptr delegate;
     if (https) {
 #ifdef BOOST_NETWORK_ENABLE_HTTPS
-      delegate.reset(new ssl_delegate(service, always_verify_peer,
-                                      certificate_filename, verify_path,
-                                      certificate_file, private_key_file));
+      delegate.reset(new ssl_delegate(
+          service, always_verify_peer, certificate_filename, verify_path,
+          certificate_file, private_key_file, ciphers, ssl_options));
 #else
       BOOST_THROW_EXCEPTION(std::runtime_error("HTTPS not supported."));
 #endif /* BOOST_NETWORK_ENABLE_HTTPS */
