@@ -19,7 +19,7 @@ namespace impl {
 struct normal_delegate : connection_delegate {
   normal_delegate(asio::io_service &service);
 
-  virtual void connect(asio::ip::tcp::endpoint &endpoint, std::string host,
+  virtual void connect(asio::ip::tcp::endpoint &endpoint, std::string host, boost::uint16_t source_port,
                        function<void(system::error_code const &)> handler);
   virtual void write(
       asio::streambuf &command_streambuf,
