@@ -10,15 +10,17 @@
 #include <boost/network/tags.hpp>
 #include <boost/network/message/directives/detail/string_directive.hpp>
 
-namespace boost { namespace network { namespace http {
+namespace boost {
+namespace network {
+namespace http {
 
-    BOOST_NETWORK_STRING_DIRECTIVE(version, version_, message.version(version_), message.version=version_);
+BOOST_NETWORK_STRING_DIRECTIVE(version, version_, message.version(version_),
+                               message.version = version_);
 
-} // namespace http
+}  // namespace http
 
-} // namespace network
+}  // namespace network
 
-} // namespace boost
+}  // namespace boost
 
-
-#endif // BOOST_NETWORK_PROTOCOL_HTTP_MESSAGE_DIRECTIVES_VERSION_HPP_20100603
+#endif  // BOOST_NETWORK_PROTOCOL_HTTP_MESSAGE_DIRECTIVES_VERSION_HPP_20100603
