@@ -9,24 +9,22 @@
 #include <boost/network/protocol/http/tags.hpp>
 #include <boost/network/support/sync_only.hpp>
 
-namespace boost { namespace network { namespace http {
+namespace boost {
+namespace network {
+namespace http {
 
-    template <class Tag>
-    struct sync_only :
-        mpl::inherit_linearly<
-            typename mpl::replace_if<
-                typename tags::components<Tag>::type,
-                is_same<mpl::placeholders::_,tags::async>,
-                tags::sync
-            >::type
-            , mpl::inherit<mpl::placeholders::_1, mpl::placeholders::_2>
-        >
-    {};
+template <class Tag>
+struct sync_only
+    : mpl::inherit_linearly<
+          typename mpl::replace_if<typename tags::components<Tag>::type,
+                                   is_same<mpl::placeholders::_, tags::async>,
+                                   tags::sync>::type,
+          mpl::inherit<mpl::placeholders::_1, mpl::placeholders::_2> > {};
 
 } /* http */
-    
+
 } /* network */
-    
+
 } /* boost */
 
 #endif /* BOOST_NETWORK_PROTOCOL_HTTP_SUPPORT_SYNC_ONLY_HPP_20100927 */
