@@ -9,30 +9,29 @@
 #include <boost/network/traits/vector.hpp>
 #include <vector>
 
-namespace boost { namespace network {
+namespace boost {
+namespace network {
 
-    template <>
-    struct vector<http::tags::http_server> {
+template <>
+struct vector<http::tags::http_server> {
 
-        template <class Type>
-        struct apply {
-            typedef std::vector<Type> type;
-        };
+  template <class Type>
+  struct apply {
+    typedef std::vector<Type> type;
+  };
+};
 
-    };
+template <>
+struct vector<http::tags::http_async_server> {
 
-    template <>
-    struct vector<http::tags::http_async_server> {
-
-        template <class Type>
-        struct apply {
-            typedef std::vector<Type> type;
-        };
-
-    };
+  template <class Type>
+  struct apply {
+    typedef std::vector<Type> type;
+  };
+};
 
 } /* network */
-    
+
 } /* boost */
 
 #endif /* BOOST_NETWORK_PROTOCOL_HTTP_TRAITS_VECTOR_HPP_20101019 */
