@@ -9,16 +9,19 @@
 #include <boost/network/tags.hpp>
 #include <boost/utility/enable_if.hpp>
 
-namespace boost { namespace network {
+namespace boost {
+namespace network {
 
-    template <class Tag, class Enable = void>
-    struct is_default_wstring : mpl::false_ {};
-    
-    template <class Tag>
-    struct is_default_wstring<Tag, typename enable_if<typename Tag::is_default_wstring>::type> : mpl::true_ {};
-    
-} // namespace network
+template <class Tag, class Enable = void>
+struct is_default_wstring : mpl::false_ {};
 
-} // namespace boost
+template <class Tag>
+struct is_default_wstring<
+    Tag,
+    typename enable_if<typename Tag::is_default_wstring>::type> : mpl::true_ {};
 
-#endif // BOOST_NETWORK_SUPPORT_STRING_CHECK_20100808
+}  // namespace network
+
+}  // namespace boost
+
+#endif  // BOOST_NETWORK_SUPPORT_STRING_CHECK_20100808
