@@ -9,16 +9,18 @@
 #include <boost/network/tags.hpp>
 #include <boost/utility/enable_if.hpp>
 
-namespace boost { namespace network {
-    
-    template <class Tag, class Enable = void>
-    struct is_keepalive : mpl::false_ {};
-    
-    template <class Tag>
-    struct is_keepalive<Tag, typename enable_if<typename Tag::is_keepalive>::type> : mpl::true_ {};
-    
+namespace boost {
+namespace network {
+
+template <class Tag, class Enable = void>
+struct is_keepalive : mpl::false_ {};
+
+template <class Tag>
+struct is_keepalive<
+    Tag, typename enable_if<typename Tag::is_keepalive>::type> : mpl::true_ {};
+
 } /* network */
-    
+
 } /* boost */
 
 #endif /* BOOST_NETWORK_SUPPORT_IS_KEEPALIVE_HPP_20100927 */
