@@ -9,17 +9,18 @@
 #include <boost/network/tags.hpp>
 #include <boost/utility/enable_if.hpp>
 
-namespace boost { namespace network {
+namespace boost {
+namespace network {
 
-    template <class Tag, class Enable = void>
-    struct is_sync : mpl::false_ {};
-    
-    template <class Tag>
-    struct is_sync<Tag, typename enable_if<typename Tag::is_sync>::type> : mpl::true_ {};
-    
-} // namespace network
+template <class Tag, class Enable = void>
+struct is_sync : mpl::false_ {};
 
-} // namespace boost
+template <class Tag>
+struct is_sync<Tag,
+               typename enable_if<typename Tag::is_sync>::type> : mpl::true_ {};
 
-#endif // BOOST_NETWORK_SUPPORT_IS_SYNC_HPP_20100623
+}  // namespace network
 
+}  // namespace boost
+
+#endif  // BOOST_NETWORK_SUPPORT_IS_SYNC_HPP_20100623
