@@ -12,22 +12,19 @@
 #include <boost/network/tags.hpp>
 #include <boost/mpl/placeholders.hpp>
 
-namespace boost { namespace network {
+namespace boost {
+namespace network {
+
+template <class Tag>
+struct sync_only
+    : mpl::inherit_linearly<
+          typename mpl::replace_if<typename tags::components<Tag>::type,
+                                   is_same<mpl::placeholders::_, tags::async>,
+                                   tags::sync>::type,
+          mpl::inherit<mpl::placeholders::_1, mpl::placeholders::_2> > {};
 
-    template <class Tag>
-    struct sync_only :
-        mpl::inherit_linearly<
-            typename mpl::replace_if<
-                typename tags::components<Tag>::type,
-                is_same<mpl::placeholders::_,tags::async>,
-                tags::sync
-            >::type
-            , mpl::inherit<mpl::placeholders::_1, mpl::placeholders::_2>
-        >
-    {};
-    
 } /* network */
-    
+
 } /* boost */
 
 #endif /* BOOST_NETWORK_SUPPORT_SYNC_ONLY_HPP_20100927 */
