@@ -29,3 +29,21 @@ BOOST_AUTO_TEST_CASE(decoding_test) {
   uri::decode(encoded, std::back_inserter(instance));
   BOOST_CHECK_EQUAL(instance, unencoded);
 }
+
+BOOST_AUTO_TEST_CASE(encoding_multibyte_test) {
+  const std::string unencoded("한글 테스트");
+  const std::string encoded("%ED%95%9C%EA%B8%80%20%ED%85%8C%EC%8A%A4%ED%8A%B8");
+
+  std::string instance;
+  uri::encode(unencoded, std::back_inserter(instance));
+  BOOST_CHECK_EQUAL(instance, encoded);
+}
+
+BOOST_AUTO_TEST_CASE(decoding_multibyte_test) {
+  const std::string unencoded("한글 테스트");
+  const std::string encoded("%ED%95%9C%EA%B8%80%20%ED%85%8C%EC%8A%A4%ED%8A%B8");
+
+  std::string instance;
+  uri::decode(encoded, std::back_inserter(instance));
+  BOOST_CHECK_EQUAL(instance, unencoded);
+}
